# SnakeScan
![PyPI version](https://badge.fury.io/py/SnakeScan.svg)
![Requires-python](https://img.shields.io/badge/requires--python-3.6+-red)
![License](https://img.shields.io/badge/License-MIT-blue.svg)
 ```
import SnakeScan
SnakeScan.run()
```
## Help
- --l  need internet to view public ip you device
- --t threading port search
- --d dos
- --s single port search
- --i information about host
- --h in host /--h port in host
## Added class Watcher:
 ```
 for SnakeScan import Watcher
 Watcher(host:str,port:int)
 ```
## Changelog
v1.5.3-Added more fast threading scan